@@ -104,13 +104,13 @@ class _RestClient(object):
                                  " remove basic.auth.user.info from the"
                                  " configuration")
 
-            userinfo = conf_copy.pop('basic.auth.user.info', '').split(':')
+            userinfo = tuple(conf_copy.pop('basic.auth.user.info', '').split(':'))
 
             if len(userinfo) != 2:
                 raise ValueError("basic.auth.user.info must be in the form"
                                  " of {username}:{password}")
 
-        self.session.auth = userinfo
+        self.session.auth = userinfo if userinfo != ('', '') else None
 
         # Any leftover keys are unknown to _RestClient
         if len(conf_copy) > 0:
@@ -252,7 +252,7 @@ class SchemaRegistryClient(object):
     """
     Schema Registry Client.
 
-    SchemaRegistryClient configuration properties(* indicates a required field):
+    SchemaRegistryClient configuration properties (* indicates a required field):
 
     +------------------------------+------+-------------------------------------------------+
     | Property name                | type | Description                                     |
@@ -260,7 +260,7 @@ class SchemaRegistryClient(object):
     | ``url`` *                    | str  | Schema Registry URL.                            |
     +------------------------------+------+-------------------------------------------------+
     |                              |      | Path to CA certificate file used                |
-    | ``ssl.ca.location`` *        | str  | to verify the Schema Registry's                 |
+    | ``ssl.ca.location``          | str  | to verify the Schema Registry's                 |
     |                              |      | private key.                                    |
     +------------------------------+------+-------------------------------------------------+
     |                              |      | Path to client's private key                    |
